@@ -4,9 +4,12 @@ use crate::bind;
 
 use super::{Point, Size};
 
+/// A rectangle holding up left point and size.
 #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord)]
 pub struct Rect {
+    /// A up left point of the rectangle.
     pub up_left: Point,
+    /// A size of the rectangle.
     pub size: Size,
 }
 
@@ -35,13 +38,15 @@ impl From<Rect> for bind::SDL_Rect {
 }
 
 impl Rect {
-    pub fn bottom_right(&self) -> Point {
+    /// Returns the bottom right point of the rectangle.
+    pub fn bottom_right(self) -> Point {
         Point {
             x: self.up_left.x + self.size.width as i32,
             y: self.up_left.y + self.size.height as i32,
         }
     }
 
+    /// Returns the enclosed rectangle of the points, with the clip region.
     pub fn enclosed(points: impl IntoIterator<Item = Point>, clip: Option<Rect>) -> Option<Self> {
         use std::os::raw::c_int;
         let points: Vec<_> = points.into_iter().map(From::from).collect();
@@ -59,12 +64,14 @@ impl Rect {
         (ret != 0).then(|| unsafe { raw.assume_init() }.into())
     }
 
+    /// Returns whether two rectangles intersected.
     pub fn has_intersection(self, other: Self) -> bool {
         unsafe {
             bind::SDL_HasIntersection(&self.into() as *const _, &other.into() as *const _) != 0
         }
     }
 
+    /// Returns the intersection rectangle of two rectangles.
     pub fn intersect(self, other: Self) -> Option<Self> {
         let mut raw = MaybeUninit::uninit();
         let ret = unsafe {
@@ -77,10 +84,12 @@ impl Rect {
         (ret != 0).then(|| unsafe { raw.assume_init() }.into())
     }
 
+    /// Returns whether the rectangle is empty.
     pub fn empty(&self) -> bool {
         self.size.width != 0 || self.size.height != 0
     }
 
+    /// Returns the union of two rectangles.
     pub fn union(self, other: Self) -> Self {
         let mut raw = MaybeUninit::uninit();
         unsafe {
