@@ -1,3 +1,5 @@
+//! Texture used to draw the image to [`Renderer`].
+
 use static_assertions::assert_not_impl_all;
 use std::marker::PhantomData;
 use std::ptr::NonNull;
@@ -13,9 +15,13 @@ mod query;
 use lock::Lock;
 pub use query::*;
 
+/// An access type for the texture.
 pub enum TextureAccess {
+    /// Cannot mutate and lock.
     Static,
+    /// Can mutate and lock.
     Streaming,
+    /// Can use as the render target in [`Renderer`].
     Target,
 }
 
@@ -38,6 +44,7 @@ impl TextureAccess {
     }
 }
 
+/// A texture used to draw the image to [`Renderer`].
 pub struct Texture<'renderer> {
     texture: NonNull<bind::SDL_Texture>,
     clip: Option<Rect>,
@@ -56,6 +63,7 @@ impl std::fmt::Debug for Texture<'_> {
 assert_not_impl_all!(Texture: Send, Sync);
 
 impl<'renderer> Texture<'renderer> {
+    /// Constructs a texture from the renderer with access type, or `Err` on failure.
     pub fn new(renderer: &'renderer Renderer<'renderer>, access: TextureAccess) -> Result<Self> {
         use super::window::ConfigExt;
         let Size { width, height } = renderer.window().size();
@@ -85,6 +93,7 @@ impl<'renderer> Texture<'renderer> {
         self.texture.as_ptr()
     }
 
+    /// Returns the alpha mod of the texture.
     pub fn alpha_mod(&self) -> u8 {
         let mut alpha = 0;
         let ret = unsafe { bind::SDL_GetTextureAlphaMod(self.as_ptr(), &mut alpha as *mut _) };
@@ -94,6 +103,7 @@ impl<'renderer> Texture<'renderer> {
         alpha
     }
 
+    /// Sets the alpha mod of the texture.
     pub fn set_alpha_mod(&self, alpha: u8) -> Result<()> {
         let ret = unsafe { bind::SDL_SetTextureAlphaMod(self.as_ptr(), alpha) };
         if ret != 0 {
@@ -101,12 +111,12 @@ impl<'renderer> Texture<'renderer> {
             if error == "That operation is not supported" {
                 return Err(SdlError::UnsupportedFeature);
             }
-            eprintln!("Setting texture alpha mod error: {}", error);
-            panic!("Unrecoverable Sdl error occurred")
+            Sdl::error_then_panic("Setting texture alpha mod");
         }
         Ok(())
     }
 
+    /// Returns the color mod of the texture.
     pub fn color_mod(&self) -> Rgb {
         let (mut r, mut g, mut b) = (0, 0, 0);
         let ret = unsafe {
@@ -123,6 +133,7 @@ impl<'renderer> Texture<'renderer> {
         Rgb { r, g, b }
     }
 
+    /// Sets the color mod of the texture.
     pub fn set_color_mod(&self, Rgb { r, g, b }: Rgb) {
         let ret = unsafe { bind::SDL_SetTextureColorMod(self.as_ptr(), r, g, b) };
         if ret != 0 {
@@ -130,18 +141,22 @@ impl<'renderer> Texture<'renderer> {
         }
     }
 
+    /// Obtains the lock for the texture in area, or whole if `None`.
     pub fn lock(&'renderer mut self, area: Option<Rect>) -> Lock<'renderer> {
         Lock::new(self, area)
     }
 
+    /// Return the clip area of the texture if available.
     pub fn clip(&self) -> &Option<Rect> {
         &self.clip
     }
 
+    /// Sets the clip area.
     pub fn set_clip(&mut self, clip: Option<Rect>) {
         self.clip = clip;
     }
 
+    /// Binds the texture to the current OpenGL context. And returns the size in the context, or `Err` on failure.
     pub fn bind_to_current_gl_context(&self) -> Result<(f32, f32)> {
         let mut width = 0f32;
         let mut height = 0f32;
@@ -155,6 +170,7 @@ impl<'renderer> Texture<'renderer> {
         }
     }
 
+    /// Unbinds the texture to the current OpenGL context, or `Err` on failure.
     pub fn unbind_from_current_gl_context(&self) -> Result<()> {
         let ret = unsafe { bind::SDL_GL_UnbindTexture(self.as_ptr()) };
         if ret != 0 {
